# hdr-sdk

[![Release](https://img.shields.io/github/v/release/alephnotation/hdr-sdk)](https://img.shields.io/github/v/release/alephnotation/hdr-sdk)
[![Build status](https://img.shields.io/github/actions/workflow/status/alephnotation/hdr-sdk/main.yml?branch=main)](https://github.com/alephnotation/hdr-sdk/actions/workflows/main.yml?query=branch%3Amain)
[![Commit activity](https://img.shields.io/github/commit-activity/m/alephnotation/hdr-sdk)](https://img.shields.io/github/commit-activity/m/alephnotation/hdr-sdk)
[![License](https://img.shields.io/github/license/alephnotation/hdr-sdk)](https://img.shields.io/github/license/alephnotation/hdr-sdk)

This is a template repository for Python projects that use uv for their dependency management.
